
  ASM

; Room Information
; Struct is:
;   byte
;     0      Wall Information
;               (bits 0-3) Room Shape (CAVERN=01xx set; STAIRS=10xx)
;               (bits 4-6) Room Colour
; <list of doors>
;            0xFF
; <list of decorative objects>
;            0xFF
;
; Door/Object Information
;    0      Door Type
;               (bits 0-1); Side (n,s,e,w or nw,ne,se,sw)
;               (bits 2-5); Type (door,door2,red,red2,blue,blue2,green,green2,yellow,yellow2,teleport,clock,bookshelf,barrel)
;               (bit 6); Unused
;               (bit 7) if set, treat coloured door as a normal door
;    1      Room Number
; If bit 7 = 0 then this is a DOOR: [0] [open?] [colour] [colour] [colour] [type] [type] [type]
; Room Number (byte) follows door

; Room types

ROOM_SQUARE			equ (0)
ROOM_HOR				equ (1)
ROOM_VER				equ (2)
ROOM_OCT				equ (3)
CAVERN_SQUARE		equ (4)
CAVERN_HOR			equ (5)
CAVERN_VER			equ (6)
STAIRS_HOR      equ (9)		; 1001
STAIRS_VER      equ (10)	; 1010



; Room Colours

ROOM_BLACK			equ (0<<4)
ROOM_BLUE				equ (1<<4)
ROOM_RED				equ (2<<4)
ROOM_MAGENTA		equ (3<<4)
ROOM_GREEN			equ (4<<4)
ROOM_CYAN				equ (5<<4)
ROOM_YELLOW			equ (6<<4)
ROOM_WHITE			equ (7<<4)


; DoorType 0
DOOR_NORTH					equ 0
DOOR_SOUTH					equ 1
DOOR_EAST						equ 2
DOOR_WEST						equ 3
; DoorType 1
DOOR_NORTHWEST			equ 4
DOOR_NORTHEAST			equ 5
DOOR_SOUTHEAST			equ 6
DOOR_SOUTHWEST			equ 7

; DoorType 2
RED_DOOR_NORTH			equ 8
RED_DOOR_SOUTH			equ 9
RED_DOOR_EAST				equ 10
RED_DOOR_WEST				equ 11
; DoorType 3
RED_DOOR_NORTHWEST	equ 12
RED_DOOR_NORTHEAST	equ 13
RED_DOOR_SOUTHEAST	equ 14
RED_DOOR_SOUTHWEST	equ 15

; DoorType 4
BLUE_DOOR_NORTH			equ 16
BLUE_DOOR_SOUTH			equ 17
BLUE_DOOR_EAST			equ 18
BLUE_DOOR_WEST			equ 19
; DoorType 5
BLUE_DOOR_NORTHWEST	equ 20
BLUE_DOOR_NORTHEAST	equ 21
BLUE_DOOR_SOUTHEAST	equ 22
BLUE_DOOR_SOUTHWEST	equ 23

; DoorType 6
GREEN_DOOR_NORTH		equ 24
GREEN_DOOR_SOUTH		equ 25
GREEN_DOOR_EAST			equ 26
GREEN_DOOR_WEST			equ 27
; DoorType 7
GREEN_DOOR_NORTHWEST	equ 28
GREEN_DOOR_NORTHEAST	equ 29
GREEN_DOOR_SOUTHEAST	equ 30
GREEN_DOOR_SOUTHWEST	equ 31

; DoorType 8
YELLOW_DOOR_NORTH	equ 32
YELLOW_DOOR_SOUTH	equ 33
YELLOW_DOOR_EAST	equ 34
YELLOW_DOOR_WEST	equ 35
; DoorType 9
YELLOW_DOOR_NORTHWEST	equ 36
YELLOW_DOOR_NORTHEAST	equ 37
YELLOW_DOOR_SOUTHEAST	equ 38
YELLOW_DOOR_SOUTHWEST	equ 39

; DoorType 10
TRAPDOOR_NORTH		equ 40
TRAPDOOR_SOUTH		equ 41
TRAPDOOR_EAST			equ 42
TRAPDOOR_WEST			equ 43

; DoorType 11
CLOCK_NORTH				equ 44
CLOCK_SOUTH				equ 45
CLOCK_EAST				equ 46
CLOCK_WEST				equ 47

; DoorType 12
BOOKSHELF_NORTH		equ 48
BOOKSHELF_SOUTH		equ 49
BOOKSHELF_EAST		equ 50
BOOKSHELF_WEST		equ 51

; DoorType 13
BARREL_NORTH			equ 52
BARREL_SOUTH			equ 53
BARREL_EAST				equ 54
BARREL_WEST				equ 55

; Door Type 14 (misc)
TRAPDOOR_CENTER		equ 56

ROOM_INSTR_END	equ 0xFF



; Room Lookup Table
RoomLookupTable:
	DEFW Room000, Room001, Room002, Room003, Room004, Room005, Room006, Room007, Room008, Room009, Room010, Room011, Room012, Room013, Room014, Room015, Room016, Room017, Room018, Room019, Room020, Room021, Room022, Room023, Room024
	DEFW Room025, Room026, Room027, Room028, Room029, Room030, Room031, Room032, Room033, Room034, Room035, Room036, Room037, Room038, Room039, Room040, Room041, Room042, Room043, Room044, Room045, Room046, Room047, Room048, Room049
	DEFW Room050, Room051, Room052, Room053, Room054, Room055, Room056, Room057, Room058, Room059, Room060, Room061, Room062, Room063, Room064, Room065, Room066, Room067, Room068, Room069, Room070, Room071, Room072, Room073, Room074
	DEFW Room075, Room076, Room077, Room078, Room079, Room080, Room081, Room082, Room083, Room084, Room085, Room086, Room087, Room088, Room089, Room090, Room091, Room092, Room093, Room094, Room095, Room096, Room097, Room098, Room099
	DEFW Room100, Room101, Room102, Room103, Room104, Room105, Room106, Room107, Room108, Room109, Room110, Room111, Room112, Room113, Room114, Room115, Room116, Room117, Room118, Room119, Room120, Room121, Room122, Room123, Room124
	DEFW Room125, Room126, Room127, Room128, Room129, Room130, Room131, Room132, Room133, Room134, Room135, Room136, Room137, Room138, Room139, Room140, Room141, Room142

	DEFW Stairs1, Stairs2, Stairs3, Stairs4, Stairs5, Stairs6

; ----------------------------------
;  GROUND FLOOR
; ----------------------------------

Room000:
	DEFB ROOM_RED|ROOM_SQUARE, 	BLUE_DOOR_NORTH, 14, DOOR_WEST, 17, DOOR_SOUTH, 24
	DEFB ROOM_INSTR_END
Room001:
	DEFB ROOM_YELLOW|ROOM_HOR, 	DOOR_EAST, 2, TRAPDOOR_CENTER, 97								; Trapdoor A
	DEFB ROOM_INSTR_END
Room002:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 1, DOOR_EAST, 3, DOOR_SOUTH, 7, CLOCK_SOUTH, 27
	DEFB ROOM_INSTR_END
Room003:
	DEFB ROOM_RED|ROOM_HOR, 	DOOR_WEST, 2, DOOR_EAST, 4
	DEFB ROOM_INSTR_END
Room004:
	DEFB ROOM_MAGENTA|ROOM_HOR, 	DOOR_WEST, 3, DOOR_EAST, 5, TRAPDOOR_SOUTH, 68	; Trapdoor B
	DEFB ROOM_INSTR_END
Room005:
	DEFB ROOM_GREEN|ROOM_HOR, 	DOOR_WEST, 4, RED_DOOR_EAST, 6, BOOKSHELF_SOUTH, 30
	DEFB ROOM_INSTR_END
Room006:
	DEFB ROOM_CYAN|ROOM_SQUARE, 	RED_DOOR_WEST, 5, GREEN_DOOR_SOUTH, 8, CLOCK_SOUTH, 31
	DEFB ROOM_INSTR_END
Room007:
	DEFB ROOM_GREEN|ROOM_VER, 	DOOR_NORTH, 2, DOOR_SOUTH, 9
	DEFB ROOM_INSTR_END
Room008:
	DEFB ROOM_YELLOW|ROOM_VER, 	GREEN_DOOR_NORTH, 6, DOOR_SOUTH, 13
	DEFB ROOM_INSTR_END
Room009:
	DEFB ROOM_CYAN|ROOM_VER, 	DOOR_NORTH, 7, RED_DOOR_SOUTH, 15, DOOR_EAST, 10
	DEFB ROOM_INSTR_END
Room010:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_WEST, 9, DOOR_EAST, 11, BARREL_SOUTH, 20
	DEFB ROOM_INSTR_END
Room011:
	DEFB ROOM_CYAN|ROOM_SQUARE, 	DOOR_WEST, 10, BLUE_DOOR_EAST, 12, BOOKSHELF_SOUTH, 21
	DEFB ROOM_INSTR_END
Room012:
	DEFB ROOM_CYAN|ROOM_OCT, 	BLUE_DOOR_WEST, 11, DOOR_EAST, 13, DOOR_SOUTH, 16, TRAPDOOR_WEST, 77	; Trapdoor C
	DEFB ROOM_INSTR_END
Room013:
	DEFB ROOM_GREEN|ROOM_HOR, 	RED_DOOR_NORTH, 8, DOOR_SOUTH, 143, DOOR_WEST, 12, DOOR_EAST, 14
	DEFB ROOM_INSTR_END
Room014:
	DEFB ROOM_MAGENTA|ROOM_OCT, 	BLUE_DOOR_SOUTH, 0, DOOR_WEST, 13
	DEFB ROOM_INSTR_END
Room015:
	DEFB ROOM_YELLOW|ROOM_VER, 	RED_DOOR_NORTH, 9, DOOR_SOUTH, 19
	DEFB ROOM_INSTR_END
Room016:
	DEFB ROOM_YELLOW|ROOM_VER, 	DOOR_NORTH, 12, DOOR_SOUTH, 22
	DEFB ROOM_INSTR_END
Room017:
	DEFB ROOM_WHITE|ROOM_HOR, 	DOOR_WEST, 16, DOOR_EAST, 0
	DEFB ROOM_INSTR_END
Room018:	; Unused
	DEFB 0, ROOM_INSTR_END
Room019:
	DEFB ROOM_WHITE|ROOM_VER, 	DOOR_NORTH, 15, DOOR_SOUTH, 25, GREEN_DOOR_EAST, 20
	DEFB ROOM_INSTR_END
Room020:
	DEFB ROOM_GREEN|ROOM_SQUARE, 	GREEN_DOOR_WEST, 19, DOOR_EAST, 21, BARREL_NORTH, 10
	DEFB ROOM_INSTR_END
Room021:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 20, DOOR_EAST, 22, BOOKSHELF_NORTH, 11
	DEFB ROOM_INSTR_END
Room022:
	DEFB ROOM_WHITE|ROOM_OCT, 	DOOR_NORTH, 16, DOOR_WEST, 21, DOOR_EAST, 23
	DEFB ROOM_INSTR_END
Room023:
	DEFB ROOM_YELLOW|ROOM_HOR, 	DOOR_NORTH, 144, GREEN_DOOR_SOUTH, 26, DOOR_WEST, 22, DOOR_EAST, 24
	DEFB ROOM_INSTR_END
Room024:
	DEFB ROOM_CYAN|ROOM_OCT, 	DOOR_NORTH, 0, DOOR_WEST, 23
	DEFB ROOM_INSTR_END
Room025:
	DEFB ROOM_YELLOW|ROOM_VER, 	DOOR_NORTH, 19, DOOR_SOUTH, 27
	DEFB ROOM_INSTR_END
Room026:
	DEFB ROOM_GREEN|ROOM_VER, 	GREEN_DOOR_NORTH, 23, DOOR_SOUTH, 31, BARREL_WEST, 53
	DEFB ROOM_INSTR_END
Room027:
	DEFB ROOM_CYAN|ROOM_SQUARE, 	DOOR_NORTH, 25, BLUE_DOOR_SOUTH, 32, DOOR_EAST, 28, CLOCK_NORTH, 2
	DEFB ROOM_INSTR_END
Room028:
	DEFB ROOM_GREEN|ROOM_HOR, 	DOOR_WEST, 27, DOOR_EAST, 29
	DEFB ROOM_INSTR_END
Room029:
	DEFB ROOM_MAGENTA|ROOM_HOR, 	DOOR_WEST, 28, DOOR_EAST, 30
	DEFB ROOM_INSTR_END
Room030:
	DEFB ROOM_RED|ROOM_HOR, 	DOOR_WEST, 29, DOOR_EAST, 31, BOOKSHELF_NORTH, 5
	DEFB ROOM_INSTR_END
Room031:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_NORTH, 26, DOOR_WEST, 30, CLOCK_NORTH, 6
	DEFB ROOM_INSTR_END
Room032:
	DEFB ROOM_RED|ROOM_VER, 	BLUE_DOOR_NORTH, 27, DOOR_SOUTH, 33
	DEFB ROOM_INSTR_END
Room033:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_NORTHWEST, 148, DOOR_NORTHEAST, 32
	DEFB ROOM_INSTR_END


; ----------------------------------
;  FIRST FLOOR
; ----------------------------------

Room034:
	DEFB ROOM_CYAN|ROOM_SQUARE,			GREEN_DOOR_WEST, 56, DOOR_SOUTH, 36
	DEFB ROOM_INSTR_END
Room035:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		DOOR_NORTH, 56, DOOR_EAST, 36
	DEFB ROOM_INSTR_END
Room036:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 35, DOOR_NORTH, 34, DOOR_EAST, 37
	DEFB ROOM_INSTR_END
Room037:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_WEST, 36, DOOR_SOUTH, 39, DOOR_EAST, 38
	DEFB ROOM_INSTR_END
Room038:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		DOOR_WEST, 37, DOOR_SOUTH, 40
	DEFB ROOM_INSTR_END
Room039:
	DEFB ROOM_GREEN|ROOM_VER, 			DOOR_NORTH, 37, DOOR_SOUTH, 43, TRAPDOOR_CENTER, 11	; Trapdoor F
	DEFB ROOM_INSTR_END
Room040:
	DEFB ROOM_CYAN|ROOM_OCT, 				DOOR_NORTH, 38, DOOR_SOUTH, 44, DOOR_EAST, 41, TRAPDOOR_EAST, 12	; Trapdoor E
	DEFB ROOM_INSTR_END
Room041:
	DEFB ROOM_GREEN|ROOM_HOR,			 	DOOR_WEST, 40, YELLOW_DOOR_SOUTH, 146, DOOR_EAST, 42
	DEFB ROOM_INSTR_END
Room042:
	DEFB ROOM_WHITE|ROOM_OCT, 			DOOR_WEST, 41, DOOR_SOUTH, 45
	DEFB ROOM_INSTR_END
Room043:
	DEFB ROOM_MAGENTA|ROOM_VER, 		DOOR_NORTH, 39, GREEN_DOOR_SOUTH, 46
	DEFB ROOM_INSTR_END
Room044:
	DEFB ROOM_YELLOW|ROOM_VER, 			DOOR_NORTH, 40, DOOR_SOUTH, 47, CLOCK_WEST, 46
	DEFB ROOM_INSTR_END
Room045:
	DEFB ROOM_RED|ROOM_VER, 				DOOR_NORTH, 42, BLUE_DOOR_SOUTH, 49
	DEFB ROOM_INSTR_END
Room046:
	DEFB ROOM_RED|ROOM_VER,				 	GREEN_DOOR_NORTH, 43, DOOR_SOUTH, 52, TRAPDOOR_NORTH, 21, CLOCK_EAST, 44	; Trapdoor G
	DEFB ROOM_INSTR_END
Room047:
	DEFB ROOM_WHITE|ROOM_OCT, 			DOOR_NORTH, 44, GREEN_DOOR_SOUTH, 53, DOOR_EAST, 48
	DEFB ROOM_INSTR_END
Room048:
	DEFB ROOM_YELLOW|ROOM_HOR, 			DOOR_WEST, 47, DOOR_NORTH, 143, DOOR_EAST, 49
	DEFB ROOM_INSTR_END
Room049:
	DEFB ROOM_CYAN|ROOM_OCT,			 	DOOR_WEST, 48, BLUE_DOOR_NORTH, 45
	DEFB ROOM_INSTR_END
Room050:
	DEFB ROOM_RED|ROOM_SQUARE, 			DOOR_SOUTH, 54, RED_DOOR_EAST, 51
	DEFB ROOM_INSTR_END
Room051:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	RED_DOOR_WEST, 50, DOOR_SOUTH, 55, YELLOW_DOOR_EAST, 52
	DEFB ROOM_INSTR_END
Room052:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	YELLOW_DOOR_WEST, 51, DOOR_NORTH, 46, DOOR_EAST, 53
	DEFB ROOM_INSTR_END
Room053:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_WEST, 52, GREEN_DOOR_NORTH, 47, BARREL_EAST, 26
	DEFB ROOM_INSTR_END
Room054:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		DOOR_NORTH, 50, DOOR_EAST, 55
	DEFB ROOM_INSTR_END
Room055:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_WEST, 54, DOOR_NORTH, 51
	DEFB ROOM_INSTR_END
Room056:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_SOUTH, 35, GREEN_DOOR_EAST, 34
	DEFB ROOM_INSTR_END



; ----------------------------------
;  THE BASEMENT
; ----------------------------------

Room057:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		BLUE_DOOR_SOUTH, 60, CLOCK_EAST, 58
	DEFB ROOM_INSTR_END
Room058:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		CLOCK_WEST, 57,  DOOR_SOUTH, 63
	DEFB ROOM_INSTR_END
Room059:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	BOOKSHELF_SOUTH, 73, YELLOW_DOOR_EAST, 60
	DEFB ROOM_INSTR_END
Room060:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	YELLOW_DOOR_WEST, 59, BLUE_DOOR_NORTH, 57, DOOR_SOUTH, 64, DOOR_EAST, 61
	DEFB ROOM_INSTR_END
Room061:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_WEST, 60, DOOR_SOUTH, 65, GREEN_DOOR_EAST, 62
	DEFB ROOM_INSTR_END
Room062:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		GREEN_DOOR_WEST, 61, DOOR_SOUTH, 66, DOOR_EAST, 63
	DEFB ROOM_INSTR_END
Room063:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 62, DOOR_NORTH, 58, DOOR_SOUTH, 67
	DEFB ROOM_INSTR_END
Room064:
	DEFB ROOM_RED|ROOM_SQUARE, 			DOOR_NORTH, 60, BLUE_DOOR_SOUTH, 69, DOOR_EAST, 65
	DEFB ROOM_INSTR_END
Room065:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		DOOR_WEST, 64, DOOR_NORTH, 61, GREEN_DOOR_SOUTHWEST, 70, YELLOW_DOOR_SOUTHEAST, 68, DOOR_EAST, 66
	DEFB ROOM_INSTR_END
Room066:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 65, DOOR_NORTH, 62, YELLOW_DOOR_SOUTHWEST, 68, RED_DOOR_SOUTHEAST, 71, GREEN_DOOR_EAST, 67
	DEFB ROOM_INSTR_END
Room067:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		GREEN_DOOR_WEST, 66, DOOR_NORTH, 63, DOOR_SOUTH, 72
	DEFB ROOM_INSTR_END
Room068:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	YELLOW_DOOR_NORTHWEST, 65, YELLOW_DOOR_NORTHEAST, 66, YELLOW_DOOR_SOUTHWEST, 70, YELLOW_DOOR_SOUTHEAST, 71
	DEFB ROOM_INSTR_END
Room069:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		BLUE_DOOR_NORTH, 64, DOOR_SOUTH, 74, DOOR_EAST, 70
	DEFB ROOM_INSTR_END
Room070:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_WEST, 69, GREEN_DOOR_NORTHWEST, 65, YELLOW_DOOR_NORTHEAST, 68, BLUE_DOOR_SOUTH, 75, DOOR_EAST, 71
	DEFB ROOM_INSTR_END
Room071:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		DOOR_WEST, 70, YELLOW_DOOR_NORTHWEST, 68, RED_DOOR_NORTHEAST, 66, BLUE_DOOR_SOUTH, 76, DOOR_EAST, 72
	DEFB ROOM_INSTR_END
Room072:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_WEST, 71, DOOR_NORTH, 67, DOOR_SOUTH, 77, TRAPDOOR_CENTER, 104; Trapdoor D
	DEFB ROOM_INSTR_END
Room073:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		BOOKSHELF_NORTH, 59, GREEN_DOOR_EAST, 74
	DEFB ROOM_INSTR_END
Room074:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		GREEN_DOOR_WEST, 73, DOOR_NORTH, 69, DOOR_EAST, 75
	DEFB ROOM_INSTR_END
Room075:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		DOOR_WEST, 74, BLUE_DOOR_NORTH, 70, DOOR_EAST, 76
	DEFB ROOM_INSTR_END
Room076:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 75, BLUE_DOOR_NORTH, 71, DOOR_EAST, 77
	DEFB ROOM_INSTR_END
Room077:
	DEFB ROOM_RED|ROOM_SQUARE, 			DOOR_WEST, 76, DOOR_NORTH, 72, DOOR_EAST, 78
	DEFB ROOM_INSTR_END
Room078:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_WEST, 77, DOOR_SOUTH, 144, DOOR_EAST, 145
	DEFB ROOM_INSTR_END

; ----------------------------------
; THE ATTIC
; ----------------------------------

Room079:
	DEFB ROOM_YELLOW|ROOM_SQUARE, 	DOOR_SOUTH, 83, CLOCK_SOUTH, 83, DOOR_EAST, 80
	DEFB ROOM_INSTR_END
Room080:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		DOOR_WEST, 79, DOOR_SOUTH, 95, GREEN_DOOR_EAST, 81, TRAPDOOR_SOUTH, 46	; Trapdoor H
	DEFB ROOM_INSTR_END
Room081:
	DEFB ROOM_YELLOW|ROOM_HOR, 			GREEN_DOOR_WEST, 80, DOOR_EAST, 82
	DEFB ROOM_INSTR_END
Room082:
	DEFB ROOM_RED|ROOM_SQUARE, 			DOOR_WEST, 81, DOOR_NORTH, 146, DOOR_SOUTH, 86
	DEFB ROOM_INSTR_END
Room083:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_NORTH, 79, CLOCK_NORTH, 79, DOOR_SOUTH, 87, DOOR_EAST, 84, TRAPDOOR_CENTER, 51	; Trapdoor J
	DEFB ROOM_INSTR_END
Room084:
	DEFB ROOM_GREEN|ROOM_SQUARE, 		DOOR_WEST, 83, DOOR_EAST, 85
	DEFB ROOM_INSTR_END
Room085:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 84, DOOR_SOUTH, 96, TRAPDOOR_EAST, 53;		Trapdoor K
	DEFB ROOM_INSTR_END
Room086:
	DEFB ROOM_RED|ROOM_VER, 				DOOR_NORTH, 82, BLUE_DOOR_SOUTH, 90
	DEFB ROOM_INSTR_END
Room087:
	DEFB ROOM_YELLOW|ROOM_VER, 			DOOR_NORTH, 83, DOOR_SOUTH, 91
	DEFB ROOM_INSTR_END
Room088:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_NORTH, 95, DOOR_EAST, 89
	DEFB ROOM_INSTR_END
Room089:
	DEFB ROOM_GREEN|ROOM_HOR, 			DOOR_WEST, 88, DOOR_EAST, 90
	DEFB ROOM_INSTR_END
Room090:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 89, BLUE_DOOR_NORTH, 86, DOOR_SOUTH, 94, TRAPDOOR_SOUTH, 31	; Trapdoor I
	DEFB ROOM_INSTR_END
Room091:
	DEFB ROOM_CYAN|ROOM_SQUARE, 		DOOR_NORTH, 87, DOOR_EAST, 92
	DEFB ROOM_INSTR_END
Room092:
	DEFB ROOM_GREEN|ROOM_HOR, 		DOOR_WEST, 91, DOOR_EAST, 93
	DEFB ROOM_INSTR_END
Room093:
	DEFB ROOM_MAGENTA|ROOM_SQUARE, 	DOOR_WEST, 92, DOOR_NORTH, 96, RED_DOOR_EAST, 94
	DEFB ROOM_INSTR_END
Room094:
	DEFB ROOM_WHITE|ROOM_SQUARE, 		RED_DOOR_WEST, 93, DOOR_NORTH, 90
	DEFB ROOM_INSTR_END
Room095:
	DEFB ROOM_YELLOW|ROOM_VER,	DOOR_NORTH, 80, DOOR_SOUTH, 88
	DEFB ROOM_INSTR_END
Room096:
	DEFB ROOM_RED|ROOM_VER,			DOOR_NORTH, 85, DOOR_SOUTH, 93
	DEFB ROOM_INSTR_END



; ----------------------------------
; THE CAVERNS
; ----------------------------------

Room097:
	DEFB ROOM_WHITE|CAVERN_SQUARE,			DOOR_EAST, 98
	DEFB ROOM_INSTR_END
Room098:
	DEFB ROOM_GREEN|CAVERN_SQUARE,			DOOR_WEST, 97, DOOR_SOUTH, 102, DOOR_EAST, 99
	DEFB ROOM_INSTR_END
Room099:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 98, DOOR_SOUTH, 103, DOOR_EAST, 100
	DEFB ROOM_INSTR_END
Room100:	; Frankenstein Room
	DEFB ROOM_WHITE|CAVERN_SQUARE,			DOOR_WEST, 99, DOOR_EAST, 101
	DEFB ROOM_INSTR_END
Room101:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 100, DOOR_SOUTH, 104, BARREL_EAST, 109
	DEFB ROOM_INSTR_END
Room102:
	DEFB ROOM_MAGENTA|CAVERN_VER,				DOOR_NORTH, 98, DOOR_SOUTH, 116
	DEFB ROOM_INSTR_END
Room103:
	DEFB ROOM_GREEN|CAVERN_SQUARE,			DOOR_NORTH, 99, DOOR_SOUTH, 117
	DEFB ROOM_INSTR_END
Room104:
	DEFB ROOM_WHITE|CAVERN_SQUARE,			DOOR_NORTH, 101, BARREL_SOUTH, 128, DOOR_EAST, 105
	DEFB ROOM_INSTR_END
Room105:
	DEFB ROOM_YELLOW|CAVERN_HOR,				DOOR_WEST, 104, BLUE_DOOR_EAST, 106
	DEFB ROOM_INSTR_END
Room106:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				BLUE_DOOR_WEST, 105, DOOR_NORTH, 114, DOOR_SOUTH, 130, RED_DOOR_EAST, 107
	DEFB ROOM_INSTR_END
Room107:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		RED_DOOR_WEST, 106, DOOR_EAST, 108
	DEFB ROOM_INSTR_END
Room108:
	DEFB ROOM_RED|CAVERN_SQUARE,				DOOR_WEST, 107, DOOR_NORTH, 115, DOOR_SOUTH, 122
	DEFB ROOM_INSTR_END
Room109:
	DEFB ROOM_GREEN|CAVERN_SQUARE,			BARREL_WEST, 101, RED_DOOR_SOUTH, 114, DOOR_EAST, 110
	DEFB ROOM_INSTR_END
Room110:
	DEFB ROOM_MAGENTA|CAVERN_HOR,				DOOR_WEST, 109, DOOR_EAST, 111
	DEFB ROOM_INSTR_END
Room111:
	DEFB ROOM_RED|CAVERN_SQUARE,				DOOR_WEST, 110, DOOR_SOUTH, 115, GREEN_DOOR_EAST, 112
	DEFB ROOM_INSTR_END
Room112:
	DEFB ROOM_GREEN|CAVERN_HOR,					GREEN_DOOR_WEST, 111, DOOR_EAST, 113
	DEFB ROOM_INSTR_END
Room113:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_WEST, 112, BARREL_SOUTH, 124
	DEFB ROOM_INSTR_END
Room114:
	DEFB ROOM_CYAN|CAVERN_VER,					RED_DOOR_NORTH, 109, DOOR_SOUTH, 106
	DEFB ROOM_INSTR_END
Room115:
	DEFB ROOM_MAGENTA|CAVERN_VER,				DOOR_NORTH, 111, DOOR_SOUTH, 108
	DEFB ROOM_INSTR_END
Room116:
	DEFB ROOM_RED|CAVERN_VER,						DOOR_NORTH, 102, DOOR_SOUTH, 125
	DEFB ROOM_INSTR_END
Room117:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_NORTH, 103, DOOR_EAST, 118
	DEFB ROOM_INSTR_END
Room118:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 117, DOOR_EAST, 119
	DEFB ROOM_INSTR_END
Room119:
	DEFB ROOM_WHITE|CAVERN_SQUARE,			DOOR_WEST, 118, DOOR_EAST, 120
	DEFB ROOM_INSTR_END
Room120:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 119, DOOR_SOUTH, 129
	DEFB ROOM_INSTR_END
Room121:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		DOOR_WEST, 145, DOOR_EAST, 122
	DEFB ROOM_INSTR_END
Room122:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_WEST, 121, DOOR_NORTH, 108, DOOR_SOUTH, 131, DOOR_EAST, 123
	DEFB ROOM_INSTR_END
Room123:
	DEFB ROOM_GREEN|CAVERN_HOR,					DOOR_WEST, 122, RED_DOOR_EAST, 124
	DEFB ROOM_INSTR_END
Room124:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		RED_DOOR_WEST, 123, BARREL_NORTH, 113
	DEFB ROOM_INSTR_END
Room125:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		DOOR_NORTH, 116, DOOR_EAST, 126, DOOR_SOUTH, 132
	DEFB ROOM_INSTR_END
Room126:
	DEFB ROOM_YELLOW|CAVERN_HOR,				DOOR_WEST, 125, DOOR_EAST, 127
	DEFB ROOM_INSTR_END
Room127:
	DEFB ROOM_WHITE|CAVERN_HOR,					DOOR_WEST, 126, DOOR_EAST, 128
	DEFB ROOM_INSTR_END
Room128:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 127, BARREL_NORTH, 119, DOOR_SOUTH, 133, GREEN_DOOR_EAST, 129
	DEFB ROOM_INSTR_END
Room129:
	DEFB ROOM_GREEN|CAVERN_SQUARE,			DOOR_WEST, 128, DOOR_NORTH, 120, DOOR_SOUTH, 134
	DEFB ROOM_INSTR_END
Room130:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_NORTH, 106, BOOKSHELF_SOUTH, 135
	DEFB ROOM_INSTR_END
Room131:
	DEFB ROOM_YELLOW|CAVERN_VER,				DOOR_NORTH, 122, DOOR_SOUTH, 137
	DEFB ROOM_INSTR_END
Room132:
	DEFB ROOM_GREEN|CAVERN_VER,					DOOR_NORTH, 125, DOOR_SOUTH, 139
	DEFB ROOM_INSTR_END
Room133:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_NORTH, 128, DOOR_EAST, 134
	DEFB ROOM_INSTR_END
Room134:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		DOOR_WEST, 133, DOOR_NORTH, 129, GREEN_DOOR_SOUTH, 140, DOOR_EAST, 135
	DEFB ROOM_INSTR_END
Room135:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		DOOR_WEST, 134, BOOKSHELF_NORTH, 130, DOOR_SOUTH, 141, BLUE_DOOR_EAST, 136
	DEFB ROOM_INSTR_END
Room136:
	DEFB ROOM_CYAN|CAVERN_HOR,					BLUE_DOOR_WEST, 135, DOOR_EAST, 137
	DEFB ROOM_INSTR_END
Room137:
	DEFB ROOM_YELLOW|CAVERN_SQUARE,			DOOR_WEST, 136, DOOR_NORTH, 131, DOOR_SOUTH, 142, DOOR_EAST, 138
	DEFB ROOM_INSTR_END
Room138:
	DEFB ROOM_WHITE|CAVERN_SQUARE,			DOOR_WEST, 137, BOOKSHELF_SOUTH, 141					; Bookshelf turns to the west!
	DEFB ROOM_INSTR_END
Room139:
	DEFB ROOM_CYAN|CAVERN_SQUARE,				DOOR_NORTH, 132, DOOR_SOUTH, 147, CLOCK_EAST, 142
	DEFB ROOM_INSTR_END
Room140:
	DEFB ROOM_RED|CAVERN_SQUARE,				GREEN_DOOR_NORTH, 134, DOOR_EAST, 141
	DEFB ROOM_INSTR_END
Room141:
	DEFB ROOM_GREEN|CAVERN_SQUARE,			DOOR_WEST, 140, DOOR_NORTH, 135, BOOKSHELF_EAST, 138	; Bookshelf turns north!
	DEFB ROOM_INSTR_END
Room142:
	DEFB ROOM_MAGENTA|CAVERN_SQUARE,		CLOCK_WEST, 139, DOOR_NORTH, 137
	DEFB ROOM_INSTR_END
Stairs1:	; Room 143
	DEFB ROOM_GREEN|STAIRS_VER, 				DOOR_NORTH, 13, DOOR_SOUTH, 48
	DEFB ROOM_INSTR_END
Stairs2:	; Room 144
	DEFB ROOM_YELLOW|STAIRS_VER, 				DOOR_NORTH, 78, DOOR_SOUTH, 23
	DEFB ROOM_INSTR_END
Stairs3:	; Room 145
	DEFB ROOM_GREEN|STAIRS_HOR, 				DOOR_WEST, 78, DOOR_EAST, 121
	DEFB ROOM_INSTR_END
Stairs4:	; Room 146
	DEFB ROOM_YELLOW|STAIRS_VER, 				YELLOW_DOOR_NORTH, 41, DOOR_SOUTH, 82
	DEFB ROOM_INSTR_END
Stairs5:	; Room 147
	DEFB ROOM_CYAN|STAIRS_VER,				 	DOOR_NORTH, 139, DOOR_SOUTH, 148
	DEFB ROOM_INSTR_END
Stairs6:	; Room 148
	DEFB ROOM_GREEN|STAIRS_VER,				 	DOOR_NORTH, 147, DOOR_SOUTH, 33
	DEFB ROOM_INSTR_END

  END ASM

